Learn R Programming

canceR (version 1.4.0)

dialogSummary_GSEA: Dialog Box to specify phenotype (variable) used in last GSEA-R to get Summary Results. This function ask the user to specify the phenotype (variable).

Description

Dialog Box to specify phenotype (variable) used in last GSEA-R to get Summary Results. This function ask the user to specify the phenotype (variable).

Usage

dialogSummary_GSEA(Variable,returnValOnCancel ="ID_CANCEL")

Arguments

Variable
phenotype
returnValOnCancel
"ID_CANCEL"

Value

variables

Examples

Run this code
load(paste(path.package("canceR"),"/data/ucec_tcga_pubGSEA1021.RData", sep=""))
## Not run: 
# #Run.GSEA()
# #getSummaryGSEA()
# ## End(Not run)

Run the code above in your browser using DataLab